/*      $Id: workspaces.h,v 1.22 2004/10/08 20:36:07 olivier Exp $
 
        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.
 
        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.
 
        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
        oroborus - (c) 2001 Ken Lynch
        xfwm4    - (c) 2002-2004 Olivier Fourdan
 
 */

#ifndef INC_WORKSPACES_H
#define INC_WORKSPACES_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xmd.h>
#include <glib.h>
#include "screen.h"
#include "client.h"

gboolean workspaceMove (ScreenInfo *, int, int, Client *);
void workspaceSwitch (ScreenInfo *, int, Client *);
void workspaceSetNames (ScreenInfo *, char *, int);
void workspaceSetCount (ScreenInfo *, int);
void workspaceUpdateArea (ScreenInfo *);

#endif /* INC_WORKSPACES_H */
